@@ -1,11 +1,9 @@
-import datetime
-import json
 import os
-from collections import OrderedDict
 
 import pytest
 
 from ..exceptions import FullTextNotAvailable
+from ..exceptions import ThrottleException
 from .model import Patent
 
 HERE = os.path.dirname(__file__)
